Utils
===========

.. _utils:

Introduction
------------
The utils module contains some helper functions that are used by other modules. However, they are open to be utilised as you wish.

Usage
-----

To use the citations module:

.. code-block:: console

    >>> import coast_core
    >>> coast_core.utils.function(to_use)

or:
.. code-block:: console

    >>> from coast_core import utils
    >>> utils.function(to_use)

Functions
---------

.. automodule:: coast_core.utils
    :members:
    :undoc-members:
    :show-inheritance:
